@@ -10,7 +10,7 @@ class RequestWrapper(object):
 
     def _send_request(self, url, payload, headers, method="POST", debug=False):
         try:
-            response = requests.request(method, url=url, data=json.dumps(payload, ensure_ascii=False), headers=headers)
+            response = requests.request(method, url=url, data=json.dumps(payload, ensure_ascii=False).encode('utf-8'), headers=headers)
             if debug:
                 message = "\n"
                 message += "%s\n" % datetime.now().strftime("%Y-%m-%d %H:%M:%s")
@@ -19,7 +19,7 @@ class RequestWrapper(object):
                 message += "Response: %s\n" % response.text
                 with open(debug, 'a+') as f:
                     f.write(message)
-            return response
+            return response.json()
         except requests.exceptions.RequestException as e:
             return {
                 "result": "KO",
@@ -30,6 +30,9 @@ class RequestWrapper(object):
     def _handle_data(self, data):
         if hasattr(data, 'text'):
             return json.loads(data.text)
+        if isinstance(data, dict) and data.get('data', False) and isinstance(data['data'], str):
+            data['data'] = json.loads(data['data'])
+            return data
         else:
             return data
 
@@ -59,7 +62,7 @@ class DirectChannel(RequestWrapper):
             "param": param,
             "data": None
         }
-        headers = {'content-type': 'application/json'}
+        headers = {'content-type': 'application/json; charset=utf-8'}
         url = "{0}/{1}".format(self.url, 'wsc_table.ashx')
         return self._handle_data(self._send_request(url=url, method="GET", payload=payload, headers=headers, debug=self.debug))
 
